Crate nitro_core

Crate nitro_core 

This library is used by Nitrolaunch to install and launch Minecraft. It aims to be the most powerful, fast, and correct implementation available, without being bloated with extra features. Implementations for installing certain modifications, like modloaders and alternative server runtimes, will be provided in extension plugins

Note: The functions in this library expect the use of the Tokio runtime and may panic if it is not used

Re-exports

pub use config::ConfigBuilder;
pub use config::Configuration;
pub use instance::ClientWindowConfig;
pub use instance::Instance;
pub use instance::InstanceConfiguration;
pub use instance::InstanceKind;
pub use io::files::paths::Paths;
pub use launch::InstanceHandle;
pub use launch::QuickPlayType;
pub use launch::WrapperCommand;
pub use nitro_auth as auth_crate;

Modules

account
Different types of accounts and authentication
config
Configuration for library functionality
instance
Instances of versions that can be launched
io
Input / output with data formats and the system
launch
Code for launching the game
net
Networking interfaces
util
Common utilities
version
Installable versions of the game

Structs

NitroCore
Wrapper around all usage of nitro_core